@@ -40,7 +40,7 @@ describe 'nova::placement' do
           :project_name        => 'service',
           :project_domain_name => 'default',
           :region_name         => 'RegionTwo',
-          :valid_interfaces    => 'internal',
+          :valid_interfaces    => 'internal,public',
           :username            => 'placement2',
           :user_domain_name    => 'default',
           :auth_url            => 'https://127.0.0.1:5000/v3',
@@ -60,44 +60,15 @@ describe 'nova::placement' do
       end
     end
 
-    context 'when settings service_name to httpd' do
+    context 'when valid_interfaces is an array' do
       before do
         params.merge!(
-          :service_name => 'httpd',
+          :valid_interfaces => ['internal', 'public']
         )
       end
 
-      it 'should not contain placement generic service' do
-        is_expected.to_not contain_nova__generic_service('nova-placement-api')
-      end
-    end
-
-  end
-
-  shared_examples 'nova::placement on Ubuntu' do
-    context 'with required parameters' do
-      it 'should not contain placement generic service' do
-        is_expected.to_not contain_nova__generic_service('nova-placement-api')
-      end
-    end
-  end
-
-  shared_examples 'nova::placement on Debian' do
-    before do
-      facts.merge!(
-        :os_package_type => 'debian',
-      )
-    end
-
-    context 'with required parameters' do
-      it 'should contain placement generic service' do
-        is_expected.to contain_nova__generic_service('nova-placement-api').with(
-          :enabled        => true,
-          :manage_service => true,
-          :package_name   => 'nova-placement-api',
-          :service_name   => 'nova-placement-api',
-          :ensure_package => 'present'
-        )
+      it 'configures the valid_interfaces parameter with a commma-separated string' do
+        is_expected.to contain_nova_config('placement/valid_interfaces').with_value('internal,public')
       end
     end
   end
@@ -109,12 +80,7 @@ describe 'nova::placement' do
       let (:facts) do
         facts.merge!(OSDefaults.get_facts())
       end
-
       it_behaves_like 'nova::placement'
-
-      if facts[:osfamily] == 'Debian'
-        it_behaves_like "nova::placement on #{facts[:operatingsystem]}"
-      end
     end
   end
 end
